/*
 * $Id: tests.c,v 1.6 2004/09/20 02:42:53 anholt Exp $
 *
 * Copyright © 2004 Eric Anholt
 *
 * Permission to use, copy, modify, distribute, and sell this software and its
 * documentation for any purpose is hereby granted without fee, provided that
 * the above copyright notice appear in all copies and that both that
 * copyright notice and this permission notice appear in supporting
 * documentation, and that the name of Eric Anholt not be used in
 * advertising or publicity pertaining to distribution of the software without
 * specific, written prior permission.  Eric Anholt makes no
 * representations about the suitability of this software for any purpose.  It
 * is provided "as is" without express or implied warranty.
 *
 * ERIC ANHOLT DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE,
 * INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO
 * EVENT SHALL ERIC ANHOLT BE LIABLE FOR ANY SPECIAL, INDIRECT OR
 * CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
 * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
 * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
 * PERFORMANCE OF THIS SOFTWARE.
 */

#include "rendercheck.h"

extern int win_width, win_height;
extern int pixmap_move_iter;
extern Bool is_verbose;

color4d colors[] = {
	{1.0, 1.0, 1.0, 1.0},
	{1.0, 0, 0, 1.0},
	{0, 1.0, 0, 1.0},
	{0, 0, 1.0, 1.0},
	{0.5, 0, 0, 0.25},
	{0.5, 0, 0, .5},
	{0.0, .5, 1.0, .5},
	{0.0, .5, 1.0, 0}
};

int num_colors = sizeof(colors) / sizeof(colors[0]);

struct op_info {
	int op;
	char *name;
} ops[] = {
	{PictOpClear, "Clear"},
	{PictOpSrc, "Src"},
	{PictOpDst, "Dst"},
	{PictOpOver, "Over"},
	{PictOpOverReverse, "OverReverse"},
	{PictOpIn, "In"},
	{PictOpInReverse, "InReverse"},
	{PictOpOut, "Out"},
	{PictOpOutReverse, "OutReverse"},
	{PictOpAtop, "Atop"},
	{PictOpAtopReverse, "AtopReverse"},
	{PictOpXor, "Xor"},
	{PictOpAdd, "Add"},
	{PictOpSaturate, "Saturate"},
	{PictOpDisjointClear, "DisjointClear"},
	{PictOpDisjointSrc, "DisjointSrc"},
	{PictOpDisjointDst, "DisjointDst"},
	{PictOpDisjointOver, "DisjointOver"},
	{PictOpDisjointOverReverse, "DisjointOverReverse"},
	{PictOpDisjointIn, "DisjointIn"},
	{PictOpDisjointInReverse, "DisjointInReverse"},
	{PictOpDisjointOut, "DisjointOut"},
	{PictOpDisjointOutReverse, "DisjointOutReverse"},
	{PictOpDisjointAtop, "DisjointAtop"},
	{PictOpDisjointAtopReverse, "DisjointAtopReverse"},
	{PictOpDisjointXor, "DisjointXor"},
	{PictOpConjointClear, "ConjointClear"},
	{PictOpConjointSrc, "ConjointSrc"},
	{PictOpConjointDst, "ConjointDst"},
	{PictOpConjointOver, "ConjointOver"},
	{PictOpConjointOverReverse, "ConjointOverReverse"},
	{PictOpConjointIn, "ConjointIn"},
	{PictOpConjointInReverse, "ConjointInReverse"},
	{PictOpConjointOut, "ConjointOut"},
	{PictOpConjointOutReverse, "ConjointOutReverse"},
	{PictOpConjointAtop, "ConjointAtop"},
	{PictOpConjointAtopReverse, "ConjointAtopReverse"},
	{PictOpConjointXor, "ConjointXor"},
};

int num_ops = sizeof(ops) / sizeof(ops[0]);




void
begin_test(Display *dpy, picture_info *win)
{
	int i, j, src, dst, mask;
	int num_dests, num_formats;
	picture_info *picture_40x40;
	picture_info *mask_20x20,*mask_10x10,*mask_30x30,*mask_40x40,*mask_768x268, *mask_766x266;
	picture_info *picture_1x1,*picture_1x1a,*picture_1x1b,*picture_10x10,*picture_20x20;
	XRenderColor rendercolor;
	XRenderPictureAttributes pa;
	XRenderPictFormat templ;
	memset(&templ, 0, sizeof(templ));
	templ.type = PictTypeDirect;

	num_formats=3;

//40x40 picture 
	picture_40x40 = (picture_info *)malloc(sizeof(picture_info));
	if (picture_40x40 == NULL)
		errx(1, "malloc error");
		i=4;
//PictStandardARGB32 0
//PictStandardRGB24  1
//PictStandardA8     2
//PictStandardA4     3
//PictStandardA1     4
//PictStandardNUM    5

	picture_40x40[0].format = XRenderFindStandardFormat(dpy,
	    i % num_formats);
	picture_40x40[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 40,
	    40, picture_40x40[0].format->depth);
	picture_40x40[0].pict = XRenderCreatePicture(dpy,
	    picture_40x40[0].d, picture_40x40[0].format, 0, NULL);

	picture_40x40[0].name = (char *)malloc(20);
	if (picture_40x40[0].name == NULL)
		errx(1, "malloc error");
	sprintf(picture_40x40[0].name, "40x40 ");
	describe_format(picture_40x40[0].name +
	    strlen(picture_40x40[0].name), 20 -
	    strlen(picture_40x40[0].name), picture_40x40[0].format);

	rendercolor.red = colors[i / num_formats].r * 65535;
	rendercolor.green = colors[i / num_formats].g * 65535;
	rendercolor.blue = colors[i / num_formats].b * 65535;
	//rendercolor.alpha = colors[i / num_formats].a * 65535;
	rendercolor.alpha = 0;
	XRenderFillRectangle(dpy, PictOpSrc, picture_40x40[0].pict,
	    &rendercolor, 0, 0, 40, 40);

//1x1 picture
	picture_1x1 = (picture_info *)malloc(sizeof(picture_info));
	if (picture_1x1 == NULL)
		errx(1, "malloc error");
//		i=7;  //RGB(green)
   		i=18; //ARGB with alpha
//	picture_1x1[0].format = XRenderFindStandardFormat(dpy,
//	    i % num_formats);
	picture_1x1[0].format = XRenderFindFormat(dpy, PictFormatType, &templ, 7);
	picture_1x1[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 1,
	    1, picture_1x1[0].format->depth);
	pa.repeat = TRUE;
//with repeat bit 
//	picture_1x1[0].pict = XRenderCreatePicture(dpy,
//	    picture_1x1[0].d, picture_1x1[0].format, CPRepeat, &pa);
//no repeat bit
	picture_1x1[0].pict = XRenderCreatePicture(dpy,
	    picture_1x1[0].d, picture_1x1[0].format, 0, NULL);

	picture_1x1[0].name = (char *)malloc(20);
	if (picture_1x1[0].name == NULL)
		errx(1, "malloc error");
	sprintf(picture_1x1[0].name, "1x1R ");
	describe_format(picture_1x1[0].name +
	    strlen(picture_1x1[0].name), 20 -
	    strlen(picture_1x1[0].name), picture_1x1[0].format);

//	rendercolor.red = colors[i / num_formats].r * 65535;
//	rendercolor.green = colors[i / num_formats].g * 65535;
//	rendercolor.blue = colors[i / num_formats].b * 65535;
//	rendercolor.alpha = colors[i / num_formats].a * 65535;
//	rendercolor.alpha = 0;
	rendercolor.red = 65535;
	rendercolor.green = 0;
	rendercolor.blue = 0;

	rendercolor.alpha = 30000;



	XRenderFillRectangle(dpy, PictOpSrc, picture_1x1[0].pict,
	    &rendercolor, 0, 0, 1, 1);

//1x1 picture a
	picture_1x1a = (picture_info *)malloc(sizeof(picture_info));
	if (picture_1x1a == NULL)
		errx(1, "malloc error");
//		i=7;  //RGB(green)
		i=18; //ARGB with alpha
	picture_1x1a[0].format = XRenderFindStandardFormat(dpy,
	    i % num_formats);
	picture_1x1a[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 1,
	    1, picture_1x1a[0].format->depth);
	pa.repeat = TRUE;
//with repeat bit 
	picture_1x1a[0].pict = XRenderCreatePicture(dpy,
	    picture_1x1a[0].d, picture_1x1a[0].format, CPRepeat, &pa);
//no repeat bit
//	picture_1x1a[0].pict = XRenderCreatePicture(dpy,
//	    picture_1x1a[0].d, picture_1x1a[0].format, 0, NULL);

	picture_1x1a[0].name = (char *)malloc(20);
	if (picture_1x1a[0].name == NULL)
		errx(1, "malloc error");
	sprintf(picture_1x1a[0].name, "1x1R ");
	describe_format(picture_1x1a[0].name +
	    strlen(picture_1x1a[0].name), 20 -
	    strlen(picture_1x1a[0].name), picture_1x1a[0].format);

//	rendercolor.red = colors[i / num_formats].r * 65535;
//	rendercolor.green = colors[i / num_formats].g * 65535;
//	rendercolor.blue = colors[i / num_formats].b * 65535;
//	rendercolor.alpha = colors[i / num_formats].a * 65535;
//	rendercolor.alpha = 0;
	rendercolor.red = 0;
	rendercolor.green = 65535;
	rendercolor.blue = 0;

	rendercolor.alpha = 50000;



	XRenderFillRectangle(dpy, PictOpSrc, picture_1x1a[0].pict,
	    &rendercolor, 0, 0, 1, 1);

//1x1 picture b
	picture_1x1b = (picture_info *)malloc(sizeof(picture_info));
	if (picture_1x1b == NULL)
		errx(1, "malloc error");
//		i=7;  //RGB(green)
		i=18; //ARGB with alpha
	picture_1x1b[0].format = XRenderFindStandardFormat(dpy,
	    i % num_formats);
	picture_1x1b[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 1,
	    1, picture_1x1b[0].format->depth);
	pa.repeat = TRUE;
//with repeat bit 
	picture_1x1b[0].pict = XRenderCreatePicture(dpy,
	    picture_1x1b[0].d, picture_1x1b[0].format, CPRepeat, &pa);
//no repeat bit
//	picture_1x1b[0].pict = XRenderCreatePicture(dpy,
//	    picture_1x1b[0].d, picture_1x1b[0].format, 0, NULL);

	picture_1x1b[0].name = (char *)malloc(20);
	if (picture_1x1b[0].name == NULL)
		errx(1, "malloc error");
	sprintf(picture_1x1b[0].name, "1x1R ");
	describe_format(picture_1x1b[0].name +
	    strlen(picture_1x1b[0].name), 20 -
	    strlen(picture_1x1b[0].name), picture_1x1b[0].format);

//	rendercolor.red = colors[i / num_formats].r * 65535;
//	rendercolor.green = colors[i / num_formats].g * 65535;
//	rendercolor.blue = colors[i / num_formats].b * 65535;
//	rendercolor.alpha = colors[i / num_formats].a * 65535;
//	rendercolor.alpha = 0;
//	rendercolor.red = 30000;
//	rendercolor.green = 20000;
//	rendercolor.blue = 10000;
	rendercolor.red = 53637;
	rendercolor.green = 44482;
	rendercolor.blue = 65535;

	rendercolor.alpha = 50000;



	XRenderFillRectangle(dpy, PictOpSrc, picture_1x1b[0].pict,
	    &rendercolor, 0, 0, 1, 1);


//10x10 picture
	picture_10x10 = (picture_info *)malloc(sizeof(picture_info));
	if (picture_10x10 == NULL)
		errx(1, "malloc error");
//		i=7;
		i=18;
	picture_10x10[0].format = XRenderFindStandardFormat(dpy,
	    i % num_formats);
	picture_10x10[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 10,
	    10, picture_10x10[0].format->depth);
	pa.repeat = TRUE;
//with repeat bit 
//	picture_10x10[0].pict = XRenderCreatePicture(dpy,
//	    picture_10x10[0].d, picture_10x10[0].format, CPRepeat, &pa);
//no repeat bit
	picture_10x10[0].pict = XRenderCreatePicture(dpy,
	    picture_10x10[0].d, picture_10x10[0].format, 0, NULL);

	picture_10x10[0].name = (char *)malloc(20);
	if (picture_10x10[0].name == NULL)
		errx(1, "malloc error");
	sprintf(picture_10x10[0].name, "1x1R ");
	describe_format(picture_10x10[0].name +
	    strlen(picture_10x10[0].name), 20 -
	    strlen(picture_10x10[0].name), picture_10x10[0].format);

//	rendercolor.red = colors[i / num_formats].r * 65535;
//	rendercolor.green = colors[i / num_formats].g * 65535;
//	rendercolor.blue = colors[i / num_formats].b * 65535;
//	rendercolor.alpha = colors[i / num_formats].a * 65535;

	rendercolor.red = 30000;
	rendercolor.green = 50000;
	rendercolor.blue = 10000;

	rendercolor.alpha = 38000;
	XRenderFillRectangle(dpy, PictOpSrc, picture_10x10[0].pict,
	    &rendercolor, 0, 0, 10, 10);

//20x20 picture
	picture_20x20 = (picture_info *)malloc(sizeof(picture_info));
	if (picture_20x20 == NULL)
		errx(1, "malloc error");
//		i=7;
		i=18;
	picture_20x20[0].format = XRenderFindStandardFormat(dpy,
	    i % num_formats);
	picture_20x20[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 20,
	    20, picture_20x20[0].format->depth);
	pa.repeat = TRUE;
//with repeat bit 
//	picture_20x20[0].pict = XRenderCreatePicture(dpy,
//	    picture_20x20[0].d, picture_20x20[0].format, CPRepeat, &pa);
//no repeat bit
	picture_20x20[0].pict = XRenderCreatePicture(dpy,
	    picture_20x20[0].d, picture_20x20[0].format, 0, NULL);

	picture_20x20[0].name = (char *)malloc(20);
	if (picture_20x20[0].name == NULL)
		errx(1, "malloc error");
	sprintf(picture_20x20[0].name, "20x20 ");
	describe_format(picture_20x20[0].name +
	    strlen(picture_20x20[0].name), 20 -
	    strlen(picture_20x20[0].name), picture_20x20[0].format);

//	rendercolor.red = colors[i / num_formats].r * 65535;
//	rendercolor.green = colors[i / num_formats].g * 65535;
//	rendercolor.blue = colors[i / num_formats].b * 65535;
//	rendercolor.alpha = colors[i / num_formats].a * 65535;

	rendercolor.red = 65535;
	rendercolor.green = 0;
	rendercolor.blue = 0;

	rendercolor.alpha = 65535;
	XRenderFillRectangle(dpy, PictOpSrc, picture_20x20[0].pict,
	    &rendercolor, 0, 0, 20, 20);

//766x266 mask 
	mask_766x266 = (picture_info *)malloc(sizeof(picture_info));
	if(mask_766x266 == NULL)
		errx(1, "malloc error");
	mask_766x266[0].format = XRenderFindStandardFormat(dpy,
	    2);

	mask_766x266[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 766,
	    266, mask_766x266[0].format->depth);
	pa.repeat = TRUE;
	mask_766x266[0].pict = XRenderCreatePicture(dpy,
	    mask_766x266[0].d, mask_766x266[0].format, 0, NULL);

	mask_766x266[0].name = (char *)malloc(20);
	if (mask_766x266[0].name == NULL)
		errx(1, "malloc error");
	sprintf(mask_766x266[0].name, "766x266 ");
	describe_format(mask_766x266[0].name +
	    strlen(mask_766x266[0].name), 20 -
	    strlen(mask_766x266[0].name), mask_766x266[0].format);
	rendercolor.red = 0;
	rendercolor.green = 0;
	rendercolor.blue = 0;
	rendercolor.alpha = 50000;
	XRenderFillRectangle(dpy, PictOpSrc, mask_766x266[0].pict,
	    &rendercolor, 0, 0, 766, 266);
	XFlush(dpy);


//768x268 mask 
	mask_768x268 = (picture_info *)malloc(sizeof(picture_info));
	if(mask_768x268 == NULL)
		errx(1, "malloc error");
	mask_768x268[0].format = XRenderFindStandardFormat(dpy,
	    2);

	mask_768x268[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 768,
	    268, mask_768x268[0].format->depth);
	pa.repeat = TRUE;
	mask_768x268[0].pict = XRenderCreatePicture(dpy,
	    mask_768x268[0].d, mask_768x268[0].format, 0, NULL);

	mask_768x268[0].name = (char *)malloc(20);
	if (mask_768x268[0].name == NULL)
		errx(1, "malloc error");
	sprintf(mask_768x268[0].name, "768x268 ");
	describe_format(mask_768x268[0].name +
	    strlen(mask_768x268[0].name), 20 -
	    strlen(mask_768x268[0].name), mask_768x268[0].format);
	rendercolor.red = 0;
	rendercolor.green = 0;
	rendercolor.blue = 0;
	rendercolor.alpha = 20000;
	XRenderFillRectangle(dpy, PictOpSrc, mask_768x268[0].pict,
	    &rendercolor, 0, 0, 768, 268);
	XFlush(dpy);

//40x40 mask 
	mask_40x40 = (picture_info *)malloc(sizeof(picture_info));
	if(mask_40x40 == NULL)
		errx(1, "malloc error");
	mask_40x40[0].format = XRenderFindStandardFormat(dpy,
	    2);

	mask_40x40[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 40,
	    40, mask_40x40[0].format->depth);
	pa.repeat = TRUE;
//with repeat bit 
//	mask_40x40[0].pict = XRenderCreatePicture(dpy,
//	    mask_40x40[0].d, mask_40x40[0].format, CPRepeat, &pa);
//no repeat bit
	mask_40x40[0].pict = XRenderCreatePicture(dpy,
	    mask_40x40[0].d, mask_40x40[0].format, 0, NULL);

	mask_40x40[0].name = (char *)malloc(20);
	if (mask_40x40[0].name == NULL)
		errx(1, "malloc error");
	sprintf(mask_40x40[0].name, "40x40 ");
	describe_format(mask_40x40[0].name +
	    strlen(mask_40x40[0].name), 20 -
	    strlen(mask_40x40[0].name), mask_40x40[0].format);
	rendercolor.red = 0;
	rendercolor.green = 0;
	rendercolor.blue = 0;
	rendercolor.alpha = 30000;
	XRenderFillRectangle(dpy, PictOpSrc, mask_40x40[0].pict,
	    &rendercolor, 0, 0, 40, 40);
	XFlush(dpy);


//30x30 mask 
	mask_30x30 = (picture_info *)malloc(sizeof(picture_info));
	if(mask_30x30 == NULL)
		errx(1, "malloc error");
	mask_30x30[0].format = XRenderFindStandardFormat(dpy,
	    2);
	mask_30x30[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 30,
	    30, mask_30x30[0].format->depth);
	mask_30x30[0].pict = XRenderCreatePicture(dpy,
	    mask_30x30[0].d, mask_30x30[0].format, 0, NULL);

	mask_30x30[0].name = (char *)malloc(20);
	if (mask_30x30[0].name == NULL)
		errx(1, "malloc error");
	sprintf(mask_30x30[0].name, "30x30 ");
	describe_format(mask_30x30[0].name +
	    strlen(mask_30x30[0].name), 20 -
	    strlen(mask_30x30[0].name), mask_30x30[0].format);
	rendercolor.red = 0;
	rendercolor.green = 0;
	rendercolor.blue = 0;
	rendercolor.alpha = 30000;
	XRenderFillRectangle(dpy, PictOpSrc, mask_30x30[0].pict,
	    &rendercolor, 0, 0, 30, 30);
	XFlush(dpy);


//20x20 mask 
	mask_20x20 = (picture_info *)malloc(sizeof(picture_info));
	if(mask_20x20 == NULL)
		errx(1, "malloc error");
	mask_20x20[0].format = XRenderFindStandardFormat(dpy,
	    2);
	mask_20x20[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 20,
	    20, mask_20x20[0].format->depth);

//no repeat bit
	mask_20x20[0].pict = XRenderCreatePicture(dpy,
	    mask_20x20[0].d, mask_20x20[0].format, 0, NULL);
//with repeat bit
//	mask_20x20[0].pict = XRenderCreatePicture(dpy,
//	    mask_20x20[0].d, mask_20x20[0].format, CPRepeat, &pa);

	mask_20x20[0].name = (char *)malloc(20);
	if (mask_20x20[0].name == NULL)
		errx(1, "malloc error");
	sprintf(mask_20x20[0].name, "20x20 ");
	describe_format(mask_20x20[0].name +
	    strlen(mask_20x20[0].name), 20 -
	    strlen(mask_20x20[0].name), mask_20x20[0].format);
	rendercolor.red = 0;
	rendercolor.green = 0;
	rendercolor.blue = 0;
	rendercolor.alpha = 65535;
	XRenderFillRectangle(dpy, PictOpSrc, mask_20x20[0].pict,
	    &rendercolor, 0, 0, 20, 20);
	XFlush(dpy);


//10x10 mask 
	mask_10x10 = (picture_info *)malloc(sizeof(picture_info));
	if(mask_10x10 == NULL)
		errx(1, "malloc error");
	mask_10x10[0].format = XRenderFindStandardFormat(dpy,
	    2);
	mask_10x10[0].d = XCreatePixmap(dpy, RootWindow(dpy, 0), 10,
	    10, mask_10x10[0].format->depth);
	mask_10x10[0].pict = XRenderCreatePicture(dpy,
	    mask_10x10[0].d, mask_10x10[0].format, 0, NULL);

	mask_10x10[0].name = (char *)malloc(20);
	if (mask_10x10[0].name == NULL)
		errx(1, "malloc error");
	sprintf(mask_10x10[0].name, "10x10 ");
	describe_format(mask_10x10[0].name +
	    strlen(mask_10x10[0].name), 20 -
	    strlen(mask_10x10[0].name), mask_10x10[0].format);
	rendercolor.red = 0;
	rendercolor.green = 0;
	rendercolor.blue = 0;
	rendercolor.alpha = 65535;
	XRenderFillRectangle(dpy, PictOpSrc, mask_10x10[0].pict,
	    &rendercolor, 0, 0, 10, 10);
	XFlush(dpy);


// XRenderComposite(Display *dpy,
// 			int  op,
// 			Picture src,
// 			Picture mask,
// 			Picture dsk,
// 			int src_x,
// 			int src_y,
// 			int mask_x,
// 			int mask_y,
// 			int dst_x,
// 			int dst_y,
// 			unsigned int width,
// 			unsigned int height)



//Src With mask 10x10, picture 1x1
	XRenderComposite(dpy, PictOpSrc, picture_1x1[0].pict, mask_10x10[0].pict, win->pict, 0, 0, 5, 5, 50, 50, 40, 40);
//Src With mask 20x20, picture 1x1
//	XRenderComposite(dpy, PictOpSrc, picture_1x1[0].pict, mask_20x20[0].pict, win->pict, 0, 0, 5, 5, 50, 50, 40, 40);
//Src With mask 30x30, picture 1x1
//	XRenderComposite(dpy, PictOpSrc, picture_1x1[0].pict, mask_30x30[0].pict, win->pict, 0, 0, 5, 5, 50, 50, 40, 40);
//Src With mask 40x40, picture 1x1
//	XRenderComposite(dpy, PictOpSrc, picture_1x1[0].pict, mask_40x40[0].pict, win->pict, 0, 0, 5, 5, 50, 50, 40, 40);
//Src No mask picture 1x1
//	XRenderComposite(dpy, PictOpSrc, picture_1x1b[0].pict, 0, win->pict, 0, 0, 0, 0, 50, 50, 40, 40);
//Src No mask picture 10x10
//	XRenderComposite(dpy, PictOpSrc, picture_10x10[0].pict, 0, win->pict, 0, 0, 0, 0, 50, 50, 40, 40);



//Over No mask picture 10x10
//	XRenderComposite(dpy, PictOpSrc, picture_20x20[0].pict, 0, win->pict, 0, 0, 0, 0, 40, 40, 40, 40);
//	XFlush(dpy);
//	XRenderComposite(dpy, PictOpOver, picture_10x10[0].pict, 0, win->pict, 18, 11, 0, 0, 50, 50, 40, 40);
//Over with mask 20x20, picture 1x1
//	XRenderComposite(dpy, PictOpSrc, picture_1x1a[0].pict, 0, win->pict, 0, 0, 0, 0, 20, 20, 50, 50);
//	XFlush(dpy);

//	XRenderComposite(dpy, PictOpOver, picture_1x1b[0].pict, 0, win->pict, 0, 0, 0, 0, 50, 50, 40, 40);
//	XFlush(dpy);
//	XRenderComposite(dpy, PictOpOver, picture_1x1[0].pict, mask_768x268[0].pict, win->pict, 0, 0, 0, 0, 0, 0, 768, 268);

//	XRenderComposite(dpy, PictOpOver, picture_1x1a[0].pict, mask_766x266[0].pict, win->pict, 0, 0, 0, 0, 0, 0, 766, 266);
//	XRenderComposite(dpy, PictOpOver, picture_1x1[0].pict, mask_30x30[0].pict, win->pict, 0, 0, 0, 0, 50, 50, 40, 40);


//PictOpClear
//	XRenderComposite(dpy, PictOpClear, picture_1x1[0].pict, mask_20x20[0].pict, win->pict, 0, 0, 5, 5, 50, 50, 40, 40);
//PictOpDst
//	XRenderComposite(dpy, PictOpDst, picture_1x1[0].pict, mask_20x20[0].pict, win->pict, 0, 0, 5, 5, 50, 50, 40, 40);
//PictOpIn
//	XRenderComposite(dpy, PictOpIn, picture_1x1[0].pict, mask_20x20[0].pict, win->pict, 0, 0, 5, 5, 50, 50, 40, 40);




	XFlush(dpy);

//	}
}
